import React from "react";
import { useForm } from "react-hook-form";
import { AvatarIcon, Button, ButtonGroup, client, Confirmation, Form, Link, Select, TextField, useWizardContext, } from "@clutch-sh/core";
import { useDataLayout } from "@clutch-sh/data-layout";
import { Wizard, WizardStep } from "@clutch-sh/wizard";
import styled from "@emotion/styled";
import { yupResolver } from "@hookform/resolvers/yup";
import LockIcon from "@mui/icons-material/Lock";
import LockOpenIcon from "@mui/icons-material/LockOpen";
import * as yup from "yup";
const ConfirmationMessage = styled.div({
    display: "flex",
    alignItems: "center",
    fontSize: "14px",
});
const schema = yup.object().shape({
    name: yup.string().required("Name is required"),
    description: yup.string().required("Description is required"),
});
const visibilityOptions = {
    PRIVATE: { label: "Private", value: "PRIVATE", startAdornment: React.createElement(LockIcon, null) },
    PUBLIC: { label: "Public", value: "PUBLIC", startAdornment: React.createElement(LockOpenIcon, null) },
};
const RepositoryDetails = () => {
    var _a, _b;
    const { register, formState: { errors }, handleSubmit, } = useForm({
        mode: "onChange",
        reValidateMode: "onChange",
        resolver: yupResolver(schema),
    });
    const { onSubmit } = useWizardContext();
    const repositoryData = useDataLayout("repositoryData");
    const repositoryOptions = repositoryData.displayValue()
        .data;
    return (React.createElement(WizardStep, { error: repositoryData.error, isLoading: repositoryData.isLoading },
        React.createElement(Form, { onSubmit: handleSubmit(onSubmit) },
            React.createElement(Select, { label: "Owner", name: "owner", onChange: value => repositoryData.updateData("owner", value), options: (_a = repositoryOptions === null || repositoryOptions === void 0 ? void 0 : repositoryOptions.availableOwners) === null || _a === void 0 ? void 0 : _a.map(owner => {
                    return { label: owner.name, startAdornment: React.createElement(AvatarIcon, { src: owner.photoUrl }) };
                }) }),
            React.createElement(TextField, { label: "Name", name: "name", onChange: e => repositoryData.updateData("name", e.target.value), helperText: errors.name ? errors.name.message : "", error: !!errors.name, formRegistration: register }),
            React.createElement(TextField, { label: "Description", name: "description", onChange: e => repositoryData.updateData("description", e.target.value), error: !!errors.description, helperText: errors.description ? errors.description.message : "", formRegistration: register }),
            React.createElement(Select, { name: "visibility", label: "Visibility", onChange: value => repositoryData.updateData("github_options.parameters.visibility", value), defaultOption: 0, options: (_b = repositoryOptions === null || repositoryOptions === void 0 ? void 0 : repositoryOptions.visibilityOptions) === null || _b === void 0 ? void 0 : _b.map(visibility => visibilityOptions === null || visibilityOptions === void 0 ? void 0 : visibilityOptions[visibility]) }),
            React.createElement(ButtonGroup, null,
                React.createElement(Button, { text: "Continue", type: "submit" })))));
};
const Confirm = () => {
    var _a;
    const repoData = useDataLayout("repoData");
    const instance = repoData.displayValue();
    return (React.createElement(WizardStep, { error: repoData.error, isLoading: repoData.isLoading },
        React.createElement(Confirmation, { action: "Repository Creation" },
            React.createElement(ConfirmationMessage, null,
                "Your new repository can be found\u00A0 ",
                React.createElement(Link, { href: ((_a = instance.data) === null || _a === void 0 ? void 0 : _a.url) || "" }, "here")))));
};
const CreateRepository = ({ heading }) => {
    const dataLayout = {
        repositoryData: {
            cache: false,
            hydrator: () => {
                return client.post("/v1/sourcecontrol/getRepositoryOptions");
            },
        },
        repoData: {
            deps: ["repositoryData"],
            cache: false,
            hydrator: resourceData => {
                return client.post("/v1/sourcecontrol/createRepository", {
                    name: resourceData.name,
                    description: resourceData.description,
                    owner: resourceData.owner,
                    github_options: resourceData.github_options,
                });
            },
        },
    };
    return (React.createElement(Wizard, { dataLayout: dataLayout, heading: heading },
        React.createElement(RepositoryDetails, { name: "Repository Details" }),
        React.createElement(Confirm, { name: "Result" })));
};
export default CreateRepository;
